@@ -34,6 +34,7 @@
 #define XN_SENSOR_5_0_PRODUCT_ID	0x0500
 #define XN_SENSOR_6_0_PRODUCT_ID	0x0600
 #define XN_SENSOR_6_0_1_PRODUCT_ID	0x0601
+#define XN_SENSOR_6_0_9_PRODUCT_ID	0x0609
 #define XN_SENSOR_MSK_VENDOR_ID	0x045E
 #define XN_SENSOR_MSK_PRODUCT_ID	0x02AE
 
@@ -406,6 +407,10 @@ XnStatus XnSensorIO::EnumerateSensors(XnConnectionString* aConnectionStrings, Xn
 	nRetVal = Enumerate(XN_SENSOR_MSK_VENDOR_ID, XN_SENSOR_MSK_PRODUCT_ID, devicesSet);
 	XN_IS_STATUS_OK(nRetVal);
 
+	// search for a v6.0.9 device
+	nRetVal = Enumerate(XN_SENSOR_VENDOR_ID, XN_SENSOR_6_0_9_PRODUCT_ID, devicesSet);
+	XN_IS_STATUS_OK(nRetVal);
+
 	// search for a v6.0.1 device
 	nRetVal = Enumerate(XN_SENSOR_VENDOR_ID, XN_SENSOR_6_0_1_PRODUCT_ID, devicesSet);
 	XN_IS_STATUS_OK(nRetVal);
